@@ -1,6 +1,6 @@
 /* b-grok.c --- comma-v parsing
 
-   Copyright (C) 2010-2012 Thien-Thi Nguyen
+   Copyright (C) 2010-2013 Thien-Thi Nguyen
 
    This file is part of GNU RCS.
 
@@ -639,7 +639,9 @@ full (struct divvy *to, struct fro *f)
 
   if (probe_keyword (g, &TINY (integrity)))
     {
-      maybe_read_atat (g, &repo->integrity);
+      if (maybe_read_atat (g, &repo->integrity)
+          && 1 < repo->integrity->count)
+        BUMMER ("spurious '@' in `%s' value", TINYKS (integrity));
       SEMI (g, integrity);
     }
 
